Skip to contents

vrule_if

vrule_if

Public fields

if_condition

if expression

then_apply

list of expressions to apply if condition is fulfilled

else_apply

list of expressions to apply if condition is not fulfilled

Methods

Inherited methods


Method new()

Initializes a conditionnal validation rule

Usage

vrule_if$new(if_condition, then_apply = list(), else_apply = list(), ...)

Arguments

if_condition

if condition

then_apply

list of expressions to apply if condition is fulfilled

else_apply

list of expressions to apply if condition is not fulfilled

...

any other arg


Method validate()

Abstract method to validate data

Usage

vrule_if$validate(value, row)

Arguments

value

value

row

row

Returns

a validation report, object of class vrule_report


Method clone()

The objects of this class are cloneable with this method.

Usage

vrule_if$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.